==> beagle-0.0.4.tar.bz2: beagle-0.0.4/Tiles/TileFromHitTemplate.cs <==
//
// TileFile.cs
//
// Copyright (C) 2004 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Diagnostics;
using System.IO;

using BU = Beagle.Util;

namespace Beagle.Tile {

	public class TileFromHitTemplate : TileFromTemplate {

		Hit hit;

		public TileFromHitTemplate (Hit _hit, 
					    string template) : base (template)
		{
			hit = _hit;
		}

		protected override void PopulateTemplate ()
		{
			Template.AddHit (hit);

			if (hit.FileInfo != null) {
				Template["LastWriteTime"] = hit.FileInfo.LastWriteTime.ToString ();
				Template["Length"] = BU.StringFu.FileLengthToString (hit.FileInfo.Length);
			} 
		}

		public Hit Hit {
			get { 
				return hit;
			}
		}
	}
}

==> beagle-0.0.11.1.tar.bz2: beagle-0.0.11.1/Tiles/TileFromHitTemplate.cs <==
//
// TileFile.cs
//
// Copyright (C) 2004 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Diagnostics;
using System.IO;

using BU = Beagle.Util;

namespace Beagle.Tile {

	public class TileFromHitTemplate : TileFromTemplate {

		public TileFromHitTemplate (Hit _hit, 
					    string template) : base (template)
		{
			this.Hit = _hit;
		}

		protected override void PopulateTemplate ()
		{
			Template.AddHit (this.Hit);

			if (this.Hit.FileInfo != null) {
				Template["LastWriteTime"] = this.Hit.FileInfo.LastWriteTime.ToString ();
				Template["Length"] = BU.StringFu.FileLengthToString (this.Hit.FileInfo.Length);
			} 
		}
	}
}
